@@ -1,8 +1,8 @@
+import sqlalchemy as sa
 from sqlalchemy.ext.hybrid import hybrid_property
 
 from .exceptions import ImproperlyConfigured
 
-
 try:
     from babel.dates import get_day_names
 except ImportError:
@@ -13,7 +13,6 @@ except ImportError:
             'module.'
         )
 
-
 try:
     from flask.ext.babel import get_locale
 except ImportError:
@@ -73,7 +72,11 @@ class TranslationHybrid(object):
         return setter
 
     def expr_factory(self, attr):
-        return lambda cls: attr
+        def expr(cls):
+            current_locale = self.cast_locale(cls, self.current_locale)
+            default_locale = self.cast_locale(cls, self.default_locale)
+            return sa.func.coalesce(attr[current_locale], attr[default_locale])
+        return expr
 
     def __call__(self, attr):
         return hybrid_property(
